#!perl -w

# test all the basic functionality

print "Content-type: text/plain\n\n";
print "ok";

__END__

this is some irrelevant data
